@@ -483,35 +483,6 @@ void linebreak_reset(linebreak_t * lbobj)
     lbobj->errnum = 0;
 }
 
-/** Get breaking rule between two classes
- *
- * From given two line breaking classes, get breaking rule determined by
- * internal data.
- * @param[in] obj linebreak object, must not be NULL.
- * @param[in] a_idx line breaking class.
- * @param[in] b_idx line breaking class.
- * @return line breaking action: MANDATORY, DIRECT, INDIRECT or PROHIBITED.
- * If action was not determined, returns DIRECT.
- *
- * @note This method gives just approximate description of line breaking
- * behavior.  Class AI will be resolved to approppriate class.
- * See also linebreak_lbrule().
- *
- * @note This method was introduced by Sombok 2.0.6. 
- *
- */
-propval_t linebreak_get_lbrule(linebreak_t * obj, propval_t b_idx,
-			       propval_t a_idx)
-{
-    if (b_idx == LB_AI)
-	b_idx = (obj->options & LINEBREAK_OPTION_EASTASIAN_CONTEXT) ?
-		LB_ID : LB_AL;
-    if (a_idx == LB_AI)
-	a_idx = (obj->options & LINEBREAK_OPTION_EASTASIAN_CONTEXT) ?
-		LB_ID : LB_AL;
-    return linebreak_lbrule(b_idx, a_idx);
-}
-
 /** Get Line Breaking Class
  *
  * Get UAX #14 line breaking class of Unicode character.
